==> 0.3.0&file=out_yasapi-0.3.0-src.tar.gz: out_yasapi-0.3.0/out_yasapi/yasapi_wwfxx.c <==
/*
 * yasapi_about.c
 * Copyright (C) 2015 Peter Belkner <pbelkner@snafu.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 */
#include <yasapi.h>

void WaveFormatExtensibleSetup(Player *pPlayer, int samplerate,
    int numchannels, int bitspersamp)
{
  WAVEFORMATEXTENSIBLE *pwfxx=&pPlayer->wfxx;
  WAVEFORMATEX *pwfx=&pwfxx->Format;

  pwfx->wFormatTag=WAVE_FORMAT_EXTENSIBLE;
  pwfx->nChannels=numchannels;
  pwfx->nSamplesPerSec=samplerate;
  pwfx->wBitsPerSample=bitspersamp;
  pwfx->cbSize=(sizeof *pwfxx)-(sizeof *pwfx);
  ////
  pPlayer->wBytesPerSample=pwfx->wBitsPerSample>>3;
  pwfx->nBlockAlign=pwfx->nChannels*pPlayer->wBytesPerSample;
  pwfx->nAvgBytesPerSec=pwfx->nSamplesPerSec*pwfx->nBlockAlign;
  ////
  pwfxx->SubFormat=KSDATAFORMAT_SUBTYPE_PCM;
  pwfxx->Samples.wValidBitsPerSample=pwfx->wBitsPerSample;

  switch (pwfx->nChannels) {
  case 1:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_CENTER;
    break;
  case 2:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_LEFT
        |SPEAKER_FRONT_RIGHT;
    break;
  case 3:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_LEFT
        |SPEAKER_FRONT_RIGHT
        |SPEAKER_LOW_FREQUENCY;
    break;
  case 5:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_RIGHT
        |SPEAKER_FRONT_CENTER
        |SPEAKER_FRONT_LEFT
        |SPEAKER_BACK_RIGHT
        |SPEAKER_BACK_LEFT;
    break;
  case 6:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_RIGHT
        |SPEAKER_FRONT_CENTER
        |SPEAKER_FRONT_LEFT
        |SPEAKER_BACK_RIGHT
        |SPEAKER_BACK_LEFT
        |SPEAKER_LOW_FREQUENCY;
    break;
  default:
    pwfxx->dwChannelMask=0;
    break;
  }
}

==> 0.4.0&file=out_yasapi-0.4.0-src.tar.gz: out_yasapi-0.4.0/out_yasapi/yasapi_wwfxx.c <==
/*
 * yasapi_about.c
 * Copyright (C) 2015 Peter Belkner <pbelkner@snafu.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 */
#include <yasapi.h>

void WaveFormatExtensibleSetup(WAVEFORMATEXTENSIBLE *pwfxx, int samplerate,
    int numchannels, int bitspersamp)
{
  WAVEFORMATEX *pwfx=&pwfxx->Format;

  pwfx->wFormatTag=WAVE_FORMAT_EXTENSIBLE;
  pwfx->nChannels=numchannels;
  pwfx->nSamplesPerSec=samplerate;
  pwfx->wBitsPerSample=bitspersamp;
  pwfx->cbSize=(sizeof *pwfxx)-(sizeof *pwfx);
  ////
  pwfx->nBlockAlign=pwfx->nChannels*(pwfx->wBitsPerSample>>3);
  pwfx->nAvgBytesPerSec=pwfx->nSamplesPerSec*pwfx->nBlockAlign;
  ////
  pwfxx->SubFormat=KSDATAFORMAT_SUBTYPE_PCM;
  pwfxx->Samples.wValidBitsPerSample=pwfx->wBitsPerSample;

  switch (pwfx->nChannels) {
  case 1:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_CENTER;
    break;
  case 2:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_LEFT
        |SPEAKER_FRONT_RIGHT;
    break;
  case 3:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_LEFT
        |SPEAKER_FRONT_RIGHT
        |SPEAKER_LOW_FREQUENCY;
    break;
  case 5:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_RIGHT
        |SPEAKER_FRONT_CENTER
        |SPEAKER_FRONT_LEFT
        |SPEAKER_BACK_RIGHT
        |SPEAKER_BACK_LEFT;
    break;
  case 6:
    pwfxx->dwChannelMask
        =SPEAKER_FRONT_RIGHT
        |SPEAKER_FRONT_CENTER
        |SPEAKER_FRONT_LEFT
        |SPEAKER_BACK_RIGHT
        |SPEAKER_BACK_LEFT
        |SPEAKER_LOW_FREQUENCY;
    break;
  default:
    pwfxx->dwChannelMask=0;
    break;
  }
}
